@@ -8,13 +8,17 @@ from kola.vals import logger
 
 
 class Connection(kola.connection.Connection):
-    def _read_message(self):
-        while not self.stream.closed():
-            # 按照官方文档，greenlet在存活的时候，是不参与内存回收的
-            # 只有greenlet在释放的时候，所有引用才会释放
 
-            job = gevent.spawn(self.stream.readline, self._on_read_complete)
-            job.join()
+    def process(self):
+        while not self.stream.closed():
+            self._read_message()
+
+    def _read_message(self):
+        # 按照官方文档，greenlet在存活的时候，是不参与内存回收的
+        # 只有greenlet在释放的时候，所有引用才会释放
+
+        job = gevent.spawn(self.stream.readline, self._on_read_complete)
+        job.join()
 
     def _on_read_complete(self, raw_data):
         """
