@@ -47,7 +47,9 @@ class GStream(object):
         接收消息
         """
 
-        data = self.rfile.readline()
+        # 异常也认为服务器断掉链接了，或者该断掉链接
+        data = safe_call(self.rfile.readline)
+
         if not data:
             # 重复调用也没关系
             self.close()
@@ -83,12 +85,5 @@ class GStream(object):
         """
         if (self.sock is not None and
                     self.sock.family in (socket.AF_INET, socket.AF_INET6)):
-            try:
-                self.sock.setsockopt(socket.IPPROTO_TCP,
-                                     socket.TCP_NODELAY, 1 if value else 0)
-            except socket.error as e:
-                # Sometimes setsockopt will fail if the socket is closed
-                # at the wrong time.  This can happen with HTTPServer
-                # resetting the value to false between requests.
-                if e.errno not in (errno.EINVAL, errno.ECONNRESET):
-                    raise
\ No newline at end of file
+            safe_call(self.sock.setsockopt,
+                      socket.IPPROTO_TCP, socket.TCP_NODELAY, 1 if value else 0)
